Select one or more policy groups for the new instance.

Groups
{$ ::trCtrl.helpText.noneAllocText $}
| {$ row.name_or_id $} ({$ row.fixed_ip $}) |
Subnets
CIDR | Allocation pools
--- | ---
Start | End
{$ subnet.cidr $} | {$ subnet.allocation_pools.length > 0 ? subnet.allocation_pools[0].start : '' $} | {$ subnet.allocation_pools.length > 0 ? subnet.allocation_pools[0].end : '' $}
| {$ allocation_pool.start $} | {$ allocation_pool.end $}
Fixed IP

Groups
{$ ::trCtrl.helpText.noneAvailText $}
{$ row.name_or_id $} |